==> cryptol-2.5.0-5-i686.pkg.tar.xz: usr/share/haskell/register/cryptol.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptol
version: 2.5.0
id: cryptol-2.5.0-k3SxOaARz2p9D6HXoVF
key: cryptol-2.5.0-k3SxOaARz2p9D6HXoVF
license: BSD3
copyright: 2013-2017 Galois Inc.
maintainer: cryptol@galois.com
homepage: http://www.cryptol.net/
synopsis: Cryptol: The Language of Cryptography
description:
    Cryptol is a domain-specific language for specifying cryptographic algorithms. A Cryptol implementation of an algorithm resembles its mathematical specification more closely than an implementation in a general purpose language. For more, see <http://www.cryptol.net/>.
category: Language
author: Galois, Inc.
exposed: True
indefinite: False
exposed-modules:
    Cryptol.Eval Cryptol.Eval.Arch Cryptol.Eval.Env Cryptol.Eval.Monad
    Cryptol.Eval.Reference Cryptol.Eval.Type Cryptol.Eval.Value
    Cryptol.ModuleSystem Cryptol.ModuleSystem.Base
    Cryptol.ModuleSystem.Env Cryptol.ModuleSystem.Interface
    Cryptol.ModuleSystem.Monad Cryptol.ModuleSystem.Name
    Cryptol.ModuleSystem.NamingEnv Cryptol.ModuleSystem.Renamer
    Cryptol.Parser Cryptol.Parser.AST Cryptol.Parser.Lexer
    Cryptol.Parser.Name Cryptol.Parser.Names Cryptol.Parser.NoInclude
    Cryptol.Parser.NoPat Cryptol.Parser.Position Cryptol.Parser.Unlit
    Cryptol.Parser.Utils Cryptol.Prims.Eval Cryptol.Prims.Syntax
    Cryptol.REPL.Command Cryptol.REPL.Monad Cryptol.REPL.Trie
    Cryptol.Symbolic Cryptol.Symbolic.Prims Cryptol.Symbolic.Value
    Cryptol.Testing.Concrete Cryptol.Testing.Random
    Cryptol.Transform.MonoValues Cryptol.Transform.Specialize
    Cryptol.TypeCheck Cryptol.TypeCheck.AST Cryptol.TypeCheck.Depends
    Cryptol.TypeCheck.Infer Cryptol.TypeCheck.InferTypes
    Cryptol.TypeCheck.Instantiate Cryptol.TypeCheck.Kind
    Cryptol.TypeCheck.Monad Cryptol.TypeCheck.PP
    Cryptol.TypeCheck.Sanity Cryptol.TypeCheck.SimpType
    Cryptol.TypeCheck.SimpleSolver Cryptol.TypeCheck.Solve
    Cryptol.TypeCheck.Solver.Class Cryptol.TypeCheck.Solver.CrySAT
    Cryptol.TypeCheck.Solver.Improve Cryptol.TypeCheck.Solver.InfNat
    Cryptol.TypeCheck.Solver.Numeric
    Cryptol.TypeCheck.Solver.Numeric.AST
    Cryptol.TypeCheck.Solver.Numeric.Defined
    Cryptol.TypeCheck.Solver.Numeric.Fin
    Cryptol.TypeCheck.Solver.Numeric.ImportExport
    Cryptol.TypeCheck.Solver.Numeric.Interval
    Cryptol.TypeCheck.Solver.Numeric.NonLin
    Cryptol.TypeCheck.Solver.Numeric.SMT
    Cryptol.TypeCheck.Solver.Numeric.Simplify
    Cryptol.TypeCheck.Solver.Numeric.SimplifyExpr
    Cryptol.TypeCheck.Solver.SMT Cryptol.TypeCheck.Solver.Selector
    Cryptol.TypeCheck.Solver.Types Cryptol.TypeCheck.Solver.Utils
    Cryptol.TypeCheck.Subst Cryptol.TypeCheck.Type
    Cryptol.TypeCheck.TypeMap Cryptol.TypeCheck.TypeOf
    Cryptol.TypeCheck.TypePat Cryptol.TypeCheck.Unify
    Cryptol.Utils.Debug Cryptol.Utils.Ident Cryptol.Utils.Misc
    Cryptol.Utils.PP Cryptol.Utils.Panic Cryptol.Utils.Patterns
    Cryptol.Version
hidden-modules: Cryptol.Parser.LexerUtils
                Cryptol.Parser.ParserUtils Cryptol.Prelude Paths_cryptol GitRev
abi: e0d8824434683094b13f5755391179dc
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cryptol-2.5.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/cryptol-2.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/cryptol
hs-libraries: HScryptol-2.5.0-k3SxOaARz2p9D6HXoVF
depends:
    base-4.10.0.0 base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    bytestring-0.10.8.2 array-0.5.2.0
    async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc containers-0.5.10.2
    deepseq-1.4.3.0 directory-1.3.0.2 filepath-1.4.1.2
    gitrev-1.3.1-Cgp0kQsBgtmnAoUzRW7fU
    GraphSCC-1.0.4-HLqyUJrTylO8FfYkusTvhD
    heredoc-0.2.0.0-4rbuntC2w7uF8duZNRyuy6
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj
    monadLib-3.7.3-I79ANJSiGFD9jThzlJcTB9
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h
    presburger-1.3.1-LY3ZfoGVtRD8KNjob154MA pretty-1.1.3.3
    process-1.6.1.0 QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK sbv-7.3-1CvuzHMfn5h3XGWyA4ekJQ
    smtLib-1.0.8-Lb4v89ZTrDc8IhNuuXZPpK
    simple-smt-0.7.0-HG8W4cUapz91k8vOeN9qe8
    syb-0.7-2rRPTNxBP6YFePrCXw4i2o text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    template-haskell-2.12.0.0 tf-random-0.5-ABDhxe3mXYlHUEE5hzgewx
    transformers-0.5.2.0 transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 time-1.8.0.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             array-0.5.2.0=044554210403f250e868a2183de060a9
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             gitrev-1.3.1-Cgp0kQsBgtmnAoUzRW7fU=5e5914ac8ea41e5f3ffe60c10fb3d810
             GraphSCC-1.0.4-HLqyUJrTylO8FfYkusTvhD=49ff6b14b0990a972248047440e31f70
             heredoc-0.2.0.0-4rbuntC2w7uF8duZNRyuy6=9c4037a2dce2955b97c513dcb23709f5
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=f1e3985ff4759dcc429559c38ecdf6c4
             monadLib-3.7.3-I79ANJSiGFD9jThzlJcTB9=3d8ee44c20c0df317ad0ff6e9d15e438
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=9b88a29fc517c1a42f17e665c48bfa0f
             presburger-1.3.1-LY3ZfoGVtRD8KNjob154MA=042cab6dbd457d0bbd95fcdffbb32699
             pretty-1.1.3.3=315e275f7256c4b9cea549968b2fd167
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1=2c4212a9c69c9d234eb81396b5fd082b
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             sbv-7.3-1CvuzHMfn5h3XGWyA4ekJQ=ff06457394fc1c64717bb992ae435262
             smtLib-1.0.8-Lb4v89ZTrDc8IhNuuXZPpK=e7cbdea15ad1a7427fe1e4bb0ed82f15
             simple-smt-0.7.0-HG8W4cUapz91k8vOeN9qe8=c92bfe5e032793c94405287f649db414
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             tf-random-0.5-ABDhxe3mXYlHUEE5hzgewx=69aa16d23e0434a9386def58aa582c19
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld=33975d5ab4ac245dea75155525ae62b2
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=ff7de6695cfb4cde5628a04fa6d123e7
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
haddock-interfaces: /usr/share/doc/cryptol/html/cryptol.haddock
haddock-html: /usr/share/doc/cryptol/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> cryptol-2.5.0-7-i686.pkg.tar.xz: usr/share/haskell/register/cryptol.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptol
version: 2.5.0
id: cryptol-2.5.0-ACI7SniROxUIvlE5i9TrQa
key: cryptol-2.5.0-ACI7SniROxUIvlE5i9TrQa
license: BSD3
copyright: 2013-2017 Galois Inc.
maintainer: cryptol@galois.com
homepage: http://www.cryptol.net/
synopsis: Cryptol: The Language of Cryptography
description:
    Cryptol is a domain-specific language for specifying cryptographic algorithms. A Cryptol implementation of an algorithm resembles its mathematical specification more closely than an implementation in a general purpose language. For more, see <http://www.cryptol.net/>.
category: Language
author: Galois, Inc.
exposed: True
indefinite: False
exposed-modules:
    Cryptol.Eval Cryptol.Eval.Arch Cryptol.Eval.Env Cryptol.Eval.Monad
    Cryptol.Eval.Reference Cryptol.Eval.Type Cryptol.Eval.Value
    Cryptol.ModuleSystem Cryptol.ModuleSystem.Base
    Cryptol.ModuleSystem.Env Cryptol.ModuleSystem.Interface
    Cryptol.ModuleSystem.Monad Cryptol.ModuleSystem.Name
    Cryptol.ModuleSystem.NamingEnv Cryptol.ModuleSystem.Renamer
    Cryptol.Parser Cryptol.Parser.AST Cryptol.Parser.Lexer
    Cryptol.Parser.Name Cryptol.Parser.Names Cryptol.Parser.NoInclude
    Cryptol.Parser.NoPat Cryptol.Parser.Position Cryptol.Parser.Unlit
    Cryptol.Parser.Utils Cryptol.Prims.Eval Cryptol.Prims.Syntax
    Cryptol.REPL.Command Cryptol.REPL.Monad Cryptol.REPL.Trie
    Cryptol.Symbolic Cryptol.Symbolic.Prims Cryptol.Symbolic.Value
    Cryptol.Testing.Concrete Cryptol.Testing.Random
    Cryptol.Transform.MonoValues Cryptol.Transform.Specialize
    Cryptol.TypeCheck Cryptol.TypeCheck.AST Cryptol.TypeCheck.Depends
    Cryptol.TypeCheck.Infer Cryptol.TypeCheck.InferTypes
    Cryptol.TypeCheck.Instantiate Cryptol.TypeCheck.Kind
    Cryptol.TypeCheck.Monad Cryptol.TypeCheck.PP
    Cryptol.TypeCheck.Sanity Cryptol.TypeCheck.SimpType
    Cryptol.TypeCheck.SimpleSolver Cryptol.TypeCheck.Solve
    Cryptol.TypeCheck.Solver.Class Cryptol.TypeCheck.Solver.CrySAT
    Cryptol.TypeCheck.Solver.Improve Cryptol.TypeCheck.Solver.InfNat
    Cryptol.TypeCheck.Solver.Numeric
    Cryptol.TypeCheck.Solver.Numeric.AST
    Cryptol.TypeCheck.Solver.Numeric.Defined
    Cryptol.TypeCheck.Solver.Numeric.Fin
    Cryptol.TypeCheck.Solver.Numeric.ImportExport
    Cryptol.TypeCheck.Solver.Numeric.Interval
    Cryptol.TypeCheck.Solver.Numeric.NonLin
    Cryptol.TypeCheck.Solver.Numeric.SMT
    Cryptol.TypeCheck.Solver.Numeric.Simplify
    Cryptol.TypeCheck.Solver.Numeric.SimplifyExpr
    Cryptol.TypeCheck.Solver.SMT Cryptol.TypeCheck.Solver.Selector
    Cryptol.TypeCheck.Solver.Types Cryptol.TypeCheck.Solver.Utils
    Cryptol.TypeCheck.Subst Cryptol.TypeCheck.Type
    Cryptol.TypeCheck.TypeMap Cryptol.TypeCheck.TypeOf
    Cryptol.TypeCheck.TypePat Cryptol.TypeCheck.Unify
    Cryptol.Utils.Debug Cryptol.Utils.Ident Cryptol.Utils.Misc
    Cryptol.Utils.PP Cryptol.Utils.Panic Cryptol.Utils.Patterns
    Cryptol.Version
hidden-modules: Cryptol.Parser.LexerUtils
                Cryptol.Parser.ParserUtils Cryptol.Prelude Paths_cryptol GitRev
abi: 442b6aeca91b6f47ead53ff9a4458f90
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cryptol-2.5.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/cryptol-2.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/cryptol
hs-libraries: HScryptol-2.5.0-ACI7SniROxUIvlE5i9TrQa
depends:
    base-4.10.0.0 base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    bytestring-0.10.8.2 array-0.5.2.0
    async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc containers-0.5.10.2
    deepseq-1.4.3.0 directory-1.3.0.2 filepath-1.4.1.2
    gitrev-1.3.1-Cgp0kQsBgtmnAoUzRW7fU
    GraphSCC-1.0.4-HLqyUJrTylO8FfYkusTvhD
    heredoc-0.2.0.0-4rbuntC2w7uF8duZNRyuy6
    monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj
    monadLib-3.7.3-I79ANJSiGFD9jThzlJcTB9
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h
    presburger-1.3.1-LY3ZfoGVtRD8KNjob154MA pretty-1.1.3.3
    process-1.6.1.0 QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
    random-1.1-DtLcP2Z2iOOC0RwcSmXjBK sbv-7.3-5VDu1hw18uRDPfTw5U8WfG
    smtLib-1.0.8-Lb4v89ZTrDc8IhNuuXZPpK
    simple-smt-0.7.1-1xmxiBj4UnZH66WV0ACaiG
    syb-0.7-2rRPTNxBP6YFePrCXw4i2o text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    template-haskell-2.12.0.0 tf-random-0.5-ABDhxe3mXYlHUEE5hzgewx
    transformers-0.5.2.0 transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 time-1.8.0.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             array-0.5.2.0=044554210403f250e868a2183de060a9
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             gitrev-1.3.1-Cgp0kQsBgtmnAoUzRW7fU=5e5914ac8ea41e5f3ffe60c10fb3d810
             GraphSCC-1.0.4-HLqyUJrTylO8FfYkusTvhD=49ff6b14b0990a972248047440e31f70
             heredoc-0.2.0.0-4rbuntC2w7uF8duZNRyuy6=9c4037a2dce2955b97c513dcb23709f5
             monad-control-1.0.2.2-IzU5oITMXX63Y9dO6OJIj=f1e3985ff4759dcc429559c38ecdf6c4
             monadLib-3.7.3-I79ANJSiGFD9jThzlJcTB9=3d8ee44c20c0df317ad0ff6e9d15e438
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=9b88a29fc517c1a42f17e665c48bfa0f
             presburger-1.3.1-LY3ZfoGVtRD8KNjob154MA=042cab6dbd457d0bbd95fcdffbb32699
             pretty-1.1.3.3=315e275f7256c4b9cea549968b2fd167
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX=31c7a57798b8306ee987164ad717d7a8
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=e54cb8ee20631772dc74b0ec551441ab
             sbv-7.3-5VDu1hw18uRDPfTw5U8WfG=1f07873163a0eb068baea691276adfb6
             smtLib-1.0.8-Lb4v89ZTrDc8IhNuuXZPpK=e7cbdea15ad1a7427fe1e4bb0ed82f15
             simple-smt-0.7.1-1xmxiBj4UnZH66WV0ACaiG=63e530739a7408577745402a84823eb3
             syb-0.7-2rRPTNxBP6YFePrCXw4i2o=db83b83263dcafbe734df45ece7027fc
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             tf-random-0.5-ABDhxe3mXYlHUEE5hzgewx=69aa16d23e0434a9386def58aa582c19
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-base-0.4.4-4U8VJPfvIYIDHbweeHN2Ld=33975d5ab4ac245dea75155525ae62b2
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=ff7de6695cfb4cde5628a04fa6d123e7
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
haddock-interfaces: /usr/share/doc/cryptol/html/cryptol.haddock
haddock-html: /usr/share/doc/cryptol/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
